package com.bonus.material.push.service;

import java.util.List;
import com.bonus.material.push.domain.PushDataReceiveInfo;

/**
 * 推送接收Service接口
 * 
 * @author xsheng
 * @date 2024-10-16
 */
public interface IPushDataReceiveInfoService {
    /**
     * 查询推送接收
     * 
     * @param id 推送接收主键
     * @return 推送接收
     */
    public PushDataReceiveInfo selectPushDataReceiveInfoById(Long id);

    /**
     * 查询推送接收列表
     * 
     * @param pushDataReceiveInfo 推送接收
     * @return 推送接收集合
     */
    public List<PushDataReceiveInfo> selectPushDataReceiveInfoList(PushDataReceiveInfo pushDataReceiveInfo);

    /**
     * 新增推送接收
     * 
     * @param pushDataReceiveInfo 推送接收
     * @return 结果
     */
    public int insertPushDataReceiveInfo(PushDataReceiveInfo pushDataReceiveInfo);

    /**
     * 修改推送接收
     * 
     * @param pushDataReceiveInfo 推送接收
     * @return 结果
     */
    public int updatePushDataReceiveInfo(PushDataReceiveInfo pushDataReceiveInfo);

    /**
     * 批量删除推送接收
     * 
     * @param ids 需要删除的推送接收主键集合
     * @return 结果
     */
    public int deletePushDataReceiveInfoByIds(Long[] ids);

    /**
     * 删除推送接收信息
     * 
     * @param id 推送接收主键
     * @return 结果
     */
    public int deletePushDataReceiveInfoById(Long id);
}
