package com.bonus.material.push.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.push.domain.PushDataReceiveInfo;
import com.bonus.material.push.service.IPushDataReceiveInfoService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 推送接收Controller
 * 
 * @author xsheng
 * @date 2024-10-16
 */
@Api(tags = "推送接收接口")
@RestController
@RequestMapping("/push_data_receive_info")
public class PushDataReceiveInfoController extends BaseController {
    @Autowired
    private IPushDataReceiveInfoService pushDataReceiveInfoService;

    /**
     * 查询推送接收列表
     */
    @ApiOperation(value = "查询推送接收列表")
    @RequiresPermissions("push:info:list")
    @GetMapping("/list")
    public TableDataInfo list(PushDataReceiveInfo pushDataReceiveInfo) {
        startPage();
        List<PushDataReceiveInfo> list = pushDataReceiveInfoService.selectPushDataReceiveInfoList(pushDataReceiveInfo);
        return getDataTable(list);
    }

    /**
     * 导出推送接收列表
     */
    @ApiOperation(value = "导出推送接收列表")
    @PreventRepeatSubmit
    @RequiresPermissions("push:info:export")
    @SysLog(title = "推送接收", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出推送接收")
    @PostMapping("/export")
    public void export(HttpServletResponse response, PushDataReceiveInfo pushDataReceiveInfo) {
        List<PushDataReceiveInfo> list = pushDataReceiveInfoService.selectPushDataReceiveInfoList(pushDataReceiveInfo);
        ExcelUtil<PushDataReceiveInfo> util = new ExcelUtil<PushDataReceiveInfo>(PushDataReceiveInfo.class);
        util.exportExcel(response, list, "推送接收数据");
    }

    /**
     * 获取推送接收详细信息
     */
    @ApiOperation(value = "获取推送接收详细信息")
    @RequiresPermissions("push:info:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(pushDataReceiveInfoService.selectPushDataReceiveInfoById(id));
    }

    /**
     * 新增推送接收
     */
    @ApiOperation(value = "新增推送接收")
    @PreventRepeatSubmit
    @RequiresPermissions("push:info:add")
    @SysLog(title = "推送接收", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增推送接收")
    @PostMapping
    public AjaxResult add(@RequestBody PushDataReceiveInfo pushDataReceiveInfo) {
        try {
            return toAjax(pushDataReceiveInfoService.insertPushDataReceiveInfo(pushDataReceiveInfo));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改推送接收
     */
    @ApiOperation(value = "修改推送接收")
    @PreventRepeatSubmit
    @RequiresPermissions("push:info:edit")
    @SysLog(title = "推送接收", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改推送接收")
    @PutMapping
    public AjaxResult edit(@RequestBody PushDataReceiveInfo pushDataReceiveInfo) {
        try {
            return toAjax(pushDataReceiveInfoService.updatePushDataReceiveInfo(pushDataReceiveInfo));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除推送接收
     */
    @ApiOperation(value = "删除推送接收")
    @PreventRepeatSubmit
    @RequiresPermissions("push:info:remove")
    @SysLog(title = "推送接收", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除推送接收")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(pushDataReceiveInfoService.deletePushDataReceiveInfoByIds(ids));
    }
}
